@@ -4,6 +4,61 @@ import six
 from kubernetes.client import ApiClient
 
 
+def svc_proxy_get(name, namespace, path, args, **kwargs):  # noqa: E501
+  local_var_params = locals()
+
+  all_params = ['name', 'namespace', 'path', 'path2']  # noqa: E501
+  all_params.append('async_req')
+  all_params.append('_return_http_data_only')
+  all_params.append('_preload_content')
+  all_params.append('_request_timeout')
+
+  for key, val in six.iteritems(local_var_params['kwargs']):
+    if key not in all_params:
+      raise TypeError(
+        "Got an unexpected keyword argument '%s'"
+        " to method connect_get_namespaced_service_proxy_with_path" % key
+      )
+    local_var_params[key] = val
+  del local_var_params['kwargs']
+  # verify the required parameter 'name' is set
+
+  path_params = {
+    'name': local_var_params['name'],
+    'namespace': local_var_params['namespace'],
+    'path': local_var_params['path'],
+  }
+
+  query_params = []
+  for arg_key, arg_val in list(args.items()):
+    query_params.append((arg_key, arg_val))  # noqa: E501
+
+  api_client = ApiClient()
+
+  header_params = {'Accept': api_client.select_header_accept(['*/*'])}
+
+  body_params = None
+  # HTTP header `Accept`
+
+  r = api_client.call_api(
+    '/api/v1/namespaces/{namespace}/services/{name}/proxy/{path}', 'GET',
+    path_params,
+    query_params,
+    header_params,
+    body=body_params,
+    post_params=[],
+    files={},
+    response_type='str',  # noqa: E501
+    auth_settings=['BearerToken'],
+    async_req=local_var_params.get('async_req'),
+    _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
+    _preload_content=local_var_params.get('_preload_content', True),
+    _request_timeout=local_var_params.get('_request_timeout'),
+    collection_formats={})
+
+  return dict(status=r[1], body=r[0].replace("'", "\""))
+
+
 def list_namespaced_resources(kind, api_group, namespace, **kwargs):
   local_var_params = locals()
 
